diff --git a/CHANGELOG.md b/CHANGELOG.md
index 3972af406..bfb066603 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -6,7 +6,7 @@
* Add support to `yescrypt` password hashing scheme
* Add new _System Logs Viewer_ (logviewer) module
* Add new `webmin server` sub-command
- * Add to set enviromental variables in Filesystem Backup module
+ * Add to set environmental variables in Filesystem Backup module
* Fix upload tracker issues with large uploads
* Fix NVMe drives status support
* Fix AlmaLinux support
diff --git a/README.md b/README.md
index 24762dc77..01b29d852 100644
--- a/README.md
+++ b/README.md
@@ -30,7 +30,7 @@ Webmin can be installed in two different ways:
Note: It is highly recommended to [add repository](https://doxfer.webmin.com/Webmin/Installation) to your system for having automatic updates.
2. By downloading, extracting [source file](https://prdownloads.sourceforge.net/webadmin/webmin-1.995.tar.gz), and running [_setup.sh_](http://www.webmin.com/tgz.html) script, with no arguments, which will setup to run it directly from this directory, or with a command-line argument, such as targeted directory.
- Note: If you are installing Webmin [on Windows](http://www.webmin.com/windows.html) system, you must run the command `perl setup.pl` instead. The Windows version depends on several programs, and modules that may not be part of the standard distribution. You will need _process.exe_ commmand, _sc.exe_ command, and _Win32::Daemon_ Perl module.
+ Note: If you are installing Webmin [on Windows](http://www.webmin.com/windows.html) system, you must run the command `perl setup.pl` instead. The Windows version depends on several programs, and modules that may not be part of the standard distribution. You will need _process.exe_ command, _sc.exe_ command, and _Win32::Daemon_ Perl module.
## Documentation
Complete set of documentation for Webmin and all of its modules can be found at out [Wiki page](https://doxfer.webmin.com/Webmin/Main_Page).
diff --git a/WebminUI/LinkTable.pm b/WebminUI/LinkTable.pm
index 94366efbd..a3468e1a2 100644
--- a/WebminUI/LinkTable.pm
+++ b/WebminUI/LinkTable.pm
@@ -145,7 +145,7 @@ $self->{'name'} = $name;
}
=head2 get_name()
-Returns the name for indentifying this table in HTML
+Returns the name for identifying this table in HTML
=cut
sub get_name
{
diff --git a/WebminUI/Table.pm b/WebminUI/Table.pm
index 9c26f18d8..9d6fd0275 100644
--- a/WebminUI/Table.pm
+++ b/WebminUI/Table.pm
@@ -402,7 +402,7 @@ $self->{'name'} = $name;
}
=head2 get_name()
-Returns the name for indentifying this table in HTML
+Returns the name for identifying this table in HTML
=cut
sub get_name
{
@@ -628,7 +628,7 @@ else {
=head2 make_url(sortcol, sortdir, paging, page, [no-searchargs], [no-pagearg])
Returns a link to this table's page, with the defaults for the various state
-fields overriden by the parameters (where defined)
+fields overridden by the parameters (where defined)
=cut
sub make_url
{
diff --git a/ajaxterm/ajaxterm/qweb.py b/ajaxterm/ajaxterm/qweb.py
index 20c509230..1e49ed34e 100644
--- a/ajaxterm/ajaxterm/qweb.py
+++ b/ajaxterm/ajaxterm/qweb.py
@@ -1293,7 +1293,7 @@ class QWebWSGIServer(SocketServer.ThreadingMixIn, BaseHTTPServer.HTTPServer):
""" QWebWSGIServer
qweb_wsgi_autorun(wsgiapp,ip='127.0.0.1',port=8080,threaded=1)
A WSGI HTTP server threaded or not and a function to automatically run your
- app according to the environement (either standalone, CGI or FastCGI).
+ app according to the environment (either standalone, CGI or FastCGI).
This feature is called QWeb autorun. If you want to To use it on your
application use the following lines at the end of the main application
@@ -1303,7 +1303,7 @@ class QWebWSGIServer(SocketServer.ThreadingMixIn, BaseHTTPServer.HTTPServer):
qweb.qweb_wsgi_autorun(your_wsgi_app)
this function will select the approriate running mode according to the
- calling environement (http-server, FastCGI or CGI).
+ calling environment (http-server, FastCGI or CGI).
"""
def __init__(self, wsgiapp, ip, port, threaded=1, log=1):
BaseHTTPServer.HTTPServer.__init__(self, (ip, port), QWebWSGIHandler)
diff --git a/bind8/bind8-lib.pl b/bind8/bind8-lib.pl
index b4231a246..17717faba 100755
--- a/bind8/bind8-lib.pl
+++ b/bind8/bind8-lib.pl
@@ -1298,7 +1298,7 @@ elsif ($type eq "DMARC") {
[ 's', $text{'value_dmarcfos'} ] ]));
}
elsif ($type eq "NSEC3PARAM") {
- # NSEC records have a hash type, flags, number of interations, salt
+ # NSEC records have a hash type, flags, number of iterations, salt
# length and salt
print &ui_table_row($text{'value_NSEC3PARAM1'},
&ui_select("value0", $v[0] || 1,
@@ -1689,7 +1689,7 @@ return $chroot.$_[0];
}
# has_ndc(exclude-mode)
-# Returns 2 if rndc is installed, 1 if ndc is instaled, or 0
+# Returns 2 if rndc is installed, 1 if ndc is installed, or 0
# Mode 2 = try ndc only, 1 = try rndc only, 0 = both
sub has_ndc
{
@@ -3715,7 +3715,7 @@ return wantarray ? @rv : $rv[0];
}
# compute_dnssec_key_size(algorithm, def-mode, size)
-# Given an algorith and size mode (0=entered, 1=average, 2=big), returns either
+# Given an algorithm and size mode (0=entered, 1=average, 2=big), returns either
# 0 and an error message or 1 and the corrected size
sub compute_dnssec_key_size
{
@@ -4055,7 +4055,7 @@ sub dt_resign_zone
}
# dt_zskroll_zone(zone-name)
-# Initates a zsk rollover operation for the zone
+# Initiates a zsk rollover operation for the zone
sub dt_zskroll_zone
{
my ($d) = @_;
@@ -4068,7 +4068,7 @@ sub dt_zskroll_zone
}
# dt_kskroll_zone(zone-name)
-# Initates a ksk rollover operation for the zone
+# Initiates a ksk rollover operation for the zone
sub dt_kskroll_zone
{
my ($d) = @_;
diff --git a/bind8/save_record.cgi b/bind8/save_record.cgi
index 9345da084..e429015e1 100755
--- a/bind8/save_record.cgi
+++ b/bind8/save_record.cgi
@@ -518,7 +518,7 @@ if ($in{'new'}) {
my $rname = &make_reverse_name($in{'value0'}, $in{'type'},
$revconf);
if ($revrec && $in{'rev'} == 2) {
- # Upate the existing reverse for the domain
+ # Update the existing reverse for the domain
&lock_file(&make_chroot($revrec->{'file'}));
&modify_record($revrec->{'file'}, $revrec,
$rname, $revrec->{'ttl'}, "IN", "PTR",
diff --git a/compare_lang.sh b/compare_lang.sh
index a4efb2ebc..5882dc69c 100755
--- a/compare_lang.sh
+++ b/compare_lang.sh
@@ -5,7 +5,7 @@
#
# (c) https://github.com/gnadelwartz, 2020
#
-# DISPLAY mising strings from one langfile:
+# DISPLAY missing strings from one langfile:
#
# ./compare_lang.sh module/lang/xx
#
@@ -36,7 +36,7 @@ while read message
do
# skip empty lines
[ "$message" == "" ] && continue
- # skip comments, __noref and log_* messsages
+ # skip comments, __noref and log_* messages
if [[ "$message" == "#"* ]] || [[ "$message" == "__norefs"* ]] || [[ "$message" == "log_"* ]]; then
echo "skip $message" 1>&2
continue
diff --git a/dhcpd/help/acl.html b/dhcpd/help/acl.html
index ad286a803..a06a8c793 100644
--- a/dhcpd/help/acl.html
+++ b/dhcpd/help/acl.html
@@ -12,7 +12,7 @@ DHCPD ACL subsystem
TARGETS:
- The main goals of acl subsystem is providing a powerfull,
+ The main goals of acl subsystem is providing a powerful,
flexible and extendable mechanism for access control of different objects
in dhcpd configuration. This objects are shared networks, subnets, groups
of hosts and hosts.
@@ -40,7 +40,7 @@ a whole object set of given type.
Global write
Per-object permissions give you a more flexible
way of access control. Per-object permissions acl exists for every object
-individual object. Today only hosts and subnets per-object acls are impemented.
+individual object. Today only hosts and subnets per-object acls are implemented.
Per-object read
Per-object write
Acl subsystem can operate in 4 different security
diff --git a/dhcpd/help/acl_info.html b/dhcpd/help/acl_info.html
index bce0b3feb..8ff25b874 100644
--- a/dhcpd/help/acl_info.html
+++ b/dhcpd/help/acl_info.html
@@ -1,7 +1,7 @@
TARGETS:
-The main goal of the ACL subsystem is providing a powerfull, flexible and
+The main goal of the ACL subsystem is providing a powerful, flexible and
extendable access control mechanism for different objects in the DHCPd
configuration. These objects are shared networks, subnets, groups of hosts
and hosts.
@@ -31,7 +31,7 @@ type:
Per-object permissions give you a more flexible way of access control.
Per-object permissions ACL exist for every individual object. Today
-per-object ACLs are impemented only for hosts and subnets:
+per-object ACLs are implemented only for hosts and subnets:
- Per-object read
- Per-object write
diff --git a/exports-nfs4/help/dir.html b/exports-nfs4/help/dir.html
index dda853e5a..290089f53 100644
--- a/exports-nfs4/help/dir.html
+++ b/exports-nfs4/help/dir.html
@@ -5,7 +5,7 @@ This is the directory being exported to the clients listed in the
Instead of mounting a number of distinct exports, an NFSv4 client sees the NFSv4 server's exports as existing inside a single filesystem, called the NFSv4 pseudofilesystem.
So for NFSv4, this directory is firsly mounted (with mount --bind) in the NFSv4 Pseudofilesystem, the pseudofilesystem is exported (if it wasn't), then the directory.
-It is preferable to export this directory without hidding it, so the client will be able to move in it without mounting it.
+It is preferable to export this directory without hiding it, so the client will be able to move in it without mounting it.
Unlike other NFS servers, Linux supports the re-exporting of a directory that has been NFS mounted from
another host, and the exporting of a directory that contains mount points for other filesystems.
diff --git a/exports/help/dir.html b/exports/help/dir.html
index dda853e5a..290089f53 100644
--- a/exports/help/dir.html
+++ b/exports/help/dir.html
@@ -5,7 +5,7 @@ This is the directory being exported to the clients listed in the
Instead of mounting a number of distinct exports, an NFSv4 client sees the NFSv4 server's exports as existing inside a single filesystem, called the NFSv4 pseudofilesystem.
So for NFSv4, this directory is firsly mounted (with mount --bind) in the NFSv4 Pseudofilesystem, the pseudofilesystem is exported (if it wasn't), then the directory.
-It is preferable to export this directory without hidding it, so the client will be able to move in it without mounting it.
+It is preferable to export this directory without hiding it, so the client will be able to move in it without mounting it.
Unlike other NFS servers, Linux supports the re-exporting of a directory that has been NFS mounted from
another host, and the exporting of a directory that contains mount points for other filesystems.
diff --git a/file/FileManager.java b/file/FileManager.java
index e4cb9b8d8..5ec0eb402 100644
--- a/file/FileManager.java
+++ b/file/FileManager.java
@@ -670,7 +670,7 @@ public class FileManager extends Applet
new PreviewWindow(this, f);
}
else if (b == refresh_b) {
- // Refesh the selected directory (and thus any subdirs)
+ // Refresh the selected directory (and thus any subdirs)
if (d == null) return;
d.refresh();
show_files(d.file);
diff --git a/file/Hierarchy.java b/file/Hierarchy.java
index abb358fc4..145226fe9 100644
--- a/file/Hierarchy.java
+++ b/file/Hierarchy.java
@@ -1,6 +1,6 @@
// Hierarchy
-// An AWT component for displaying a tree-like heirachy, with each node
-// having an icon and a name. This heirachy can be expanded or contracted
+// An AWT component for displaying a tree-like hierarchy, with each node
+// having an icon and a name. This hierarchy can be expanded or contracted
// by the user.
import java.awt.*;
import java.util.Vector;
diff --git a/firewall/config.info b/firewall/config.info
index 73d228416..42fd5d9bc 100644
--- a/firewall/config.info
+++ b/firewall/config.info
@@ -9,7 +9,7 @@ after_cmd=Command to run after changing rules,3,None
before_apply_cmd=Command to run before applying configuration,3,None
after_apply_cmd=Command to run after applying configuration,3,None
force_init=Always start firewall from init script on Debian,1,1-Yes,0-No
-filter_chain=Comma sepeated list of regexes to filter out chains not managed by firewall,0
+filter_chain=Comma seperated list of regexes to filter out chains not managed by firewall,0
iface=Network interface to activate firewall on,3,Automatic
line2=IPv4 configuration,11
save_file=File to save/edit IPv4 rules,3,Use operating system or Webmin default
diff --git a/firewall/firewall-lib.pl b/firewall/firewall-lib.pl
index 9cc929b55..4e81fca28 100755
--- a/firewall/firewall-lib.pl
+++ b/firewall/firewall-lib.pl
@@ -454,7 +454,7 @@ if ($config{'after_cmd'}) {
}
# run_before_apply_command()
-# Runs the before-applying command, if any. If it failes, returns the error
+# Runs the before-applying command, if any. If it fails, returns the error
# message output
sub run_before_apply_command
{
diff --git a/firewall/index.cgi b/firewall/index.cgi
index 2df3dc179..a2f0ab296 100755
--- a/firewall/index.cgi
+++ b/firewall/index.cgi
@@ -213,7 +213,7 @@ else {
if ($config{'filter_chain'}) {
foreach $filter (split(',', $config{'filter_chain'})) {
if($c =~ /^$filter$/) {
- # not managed by firewall, do not dispaly or modify
+ # not managed by firewall, do not display or modify
print "".$text{'index_filter_chain'}."
\n";
next CHAIN;
}
diff --git a/gray-theme/left.cgi b/gray-theme/left.cgi
index 53b992a45..5bbdef807 100755
--- a/gray-theme/left.cgi
+++ b/gray-theme/left.cgi
@@ -102,7 +102,7 @@ if (&get_product_name() eq 'webmin' && # For Webmin
'icon' => '/images/mail-small.gif' });
}
-# Show refesh modules link, for master admin
+# Show refresh modules link, for master admin
if (&foreign_available("webmin")) {
push(@leftmenu, { 'type' => 'item',
'desc' => $text{'main_refreshmods'},
diff --git a/gray-theme/theme.pl b/gray-theme/theme.pl
index eadbd4b14..2691157ee 100755
--- a/gray-theme/theme.pl
+++ b/gray-theme/theme.pl
@@ -199,7 +199,7 @@ if ($action eq 'create' || $action eq 'delete' || $action eq 'modify') {
$ref = 1;
}
else {
- # Only refesh if showing unread count
+ # Only refresh if showing unread count
if (defined(&mailbox::should_show_unread) &&
&mailbox::should_show_unread($folder)) {
$ref = 1;
diff --git a/ipsec/help/edit.html b/ipsec/help/edit.html
index 4ef538043..0aa534dfc 100644
--- a/ipsec/help/edit.html
+++ b/ipsec/help/edit.html
@@ -12,7 +12,7 @@ for each connection and their recommended settings are listed below :
- A short name for this connection with no spaces.
- At IPsec startup
- If Add connection is chosen, this connection will only be established
- when explicity started. If Start connection is chosen then it will
+ when explicitly started. If Start connection is chosen then it will
be launched as soon as the IPsec server is started. The former option is
best for tunnels to remote systems that are only periodically active, while
the latter is suitable for permanent VPN links.
@@ -22,7 +22,7 @@ for each connection and their recommended settings are listed below :
- Should also be left set to Default.
-Addtional information must be supplied for the systems on either end of the
+Additional information must be supplied for the systems on either end of the
connection. This must be the same on both systems, although generally the
Local and Remote details are swapped so that the settings for
this host are always in the Local or left system's settings section.
diff --git a/javascript-lib.pl b/javascript-lib.pl
index 245c61b2f..57618e345 100755
--- a/javascript-lib.pl
+++ b/javascript-lib.pl
@@ -16,11 +16,11 @@
# Available Functions #
# *jroll_over #
# -This gives you simple mouse over functions on graphics #
-# and includea a link. #
+# and include a link. #
# -Usage = &jroll_over("url", "name", "border", "imgoff", "imgon"); #
# *jimg_preload #
# -Preloads any number of given images. #
-# -Usage = &jimg_preload("image/1.gif", "imgage/u.gif"); #
+# -Usage = &jimg_preload("image/1.gif", "image/u.gif"); #
# *jimg_update #
# -Updates any image on your page that has a name #
# -Usage = &jimg_update("imgname", "image/toload.gif"); #
@@ -144,7 +144,7 @@ sub jalert {
print "\n";
}
-#opens a specified url in a seprate window
+#opens a specified url in a separate window
sub jwindow {
my ($url, $name, $width, $height) = @_;
if (!$width) { $width = "300"; }
diff --git a/ldap-client/help/base.html b/ldap-client/help/base.html
index 50721b229..36f37f770 100644
--- a/ldap-client/help/base.html
+++ b/ldap-client/help/base.html
@@ -1,6 +1,6 @@
-An LDAP server's databsae is organized heirarchially, typically with
+An LDAP server's database is organized heirarchially, typically with
different branches in the tree for users, groups and other services. This
page allows you to select where in the LDAP database to search for
different types of information, and how deep to search for each.
diff --git a/ldap-client/help/browser.html b/ldap-client/help/browser.html
index dd30b0ae4..38891fd75 100644
--- a/ldap-client/help/browser.html
+++ b/ldap-client/help/browser.html
@@ -1,7 +1,7 @@
This page provides a simple way of exporing the data in the currently
-configured LDAP server. It is useful for fining where in the heirarchy
+configured LDAP server. It is useful for fining where in the hierarchy
users and groups are stored, so that they can be correctly entered on
the LDAP Search Bases page.
diff --git a/ldap-server/help/browser.html b/ldap-server/help/browser.html
index 3e2f5d3d0..f0e8e2a41 100644
--- a/ldap-server/help/browser.html
+++ b/ldap-server/help/browser.html
@@ -1,10 +1,10 @@
-This page allows you to navigate through the heirarchy of objects in your
+This page allows you to navigate through the hierarchy of objects in your
LDAP database, create and remove objects, and edit their attributes.
The DN for the object being managed is always shown in the Browsing
field - to quickly navigate to another object, enter a new DN and click
-Show. To move up the heirarchy, click on Browse Parent.
+Show. To move up the hierarchy, click on Browse Parent.
The rest of the page is divided into two tabs :
diff --git a/logrotate/help/global.html b/logrotate/help/global.html
index 6c61ec94b..76c5b5465 100644
--- a/logrotate/help/global.html
+++ b/logrotate/help/global.html
@@ -1,6 +1,6 @@
-The rotation options on this page apply to all log files, unless overriden
+The rotation options on this page apply to all log files, unless overridden
by settings under a particular log. This allows you to define a common
schedule, maximum size or number of old logs to keep for all files on your
system. Commonly used fields on this page include :
diff --git a/logrotate/help/intro.html b/logrotate/help/intro.html
index dba78eb6f..9f2f39671 100644
--- a/logrotate/help/intro.html
+++ b/logrotate/help/intro.html
@@ -20,7 +20,7 @@ old copies are kept and so on. You can edit the options for a log by clicking
on its filename, or add a new log file using the link at the bottom or top
of the table.
-Many Linux distribtions include logrotate as standard, and come with
+Many Linux distributions include logrotate as standard, and come with
configurations for rotating the logs of included servers like Apache and
Squid. So even if you have never used this module before, many log files
may already be listed on the main page. Often
diff --git a/majordomo/lang/en b/majordomo/lang/en
index 5bc766f9a..abdd51515 100644
--- a/majordomo/lang/en
+++ b/majordomo/lang/en
@@ -4,7 +4,7 @@ index_eprograms=The majordomo directory $1 does not exist. Maybe your module configuration is incorrect, or majordomo is not installed.
index_emdomdir=The $1 variable in your majordomo config file is set to $2, which does not exist.
-index_esendmail=The $1 seting of your modul configuration is set to $2, which does not exist. Maybe your module configuration is incorrect, or no mailer deamon is installed.
+index_esendmail=The $1 seting of your modul configuration is set to $2, which does not exist. Maybe your module configuration is incorrect, or no mailer daemon is installed.
index_esendmail2=Sendmail is either not installed or not properly set up on your system. Check the Sendmail module configuration.
index_epostfix=Postfix is either not installed or not properly set up on your system. Check the Postfix module configuration.
index_esendmail3=The Sendmail Webmin module needed to manage aliases is not installed.
diff --git a/miniserv.pl b/miniserv.pl
index aa3431852..c13aa5bb6 100755
--- a/miniserv.pl
+++ b/miniserv.pl
@@ -5221,7 +5221,7 @@ sub disconnect_userdb
{
my ($str, $h) = @_;
if ($str =~ /^(mysql|postgresql):/) {
- # DBI disconnnect
+ # DBI disconnect
$h->disconnect();
}
elsif ($str =~ /^ldap:/) {
diff --git a/mon/help/service.html b/mon/help/service.html
index 9ee330f9b..13a202c68 100644
--- a/mon/help/service.html
+++ b/mon/help/service.html
@@ -198,9 +198,9 @@ graph indicate failure.
Monitor suppression.
If it is set to "m",
-then the dependency expression will be evaulated
+then the dependency expression will be evaluated
before the monitor for the service is about to run.
-If the evaulation succeeds, then the monitor
+If the evaluation succeeds, then the monitor
will be run. Otherwise, the monitor will not
be run and the status of the service will remain
the same.
@@ -338,7 +338,7 @@ the
keyword, followed by an optional
exit
-parmeter, and arguments which are interpreted the same as
+parameter, and arguments which are interpreted the same as
the
monitor
diff --git a/mon/mon-lib.pl b/mon/mon-lib.pl
index ce423ced6..218061aa3 100755
--- a/mon/mon-lib.pl
+++ b/mon/mon-lib.pl
@@ -54,7 +54,7 @@ while() {
push(@rv, $str);
}
elsif (/^(\s*)(\S+)\s*(.*)$/) {
- # Normal directive, possibly in a heirachy
+ # Normal directive, possibly in a hierarchy
local $str = { 'name' => $2,
'values' => [ split(/\s+/, $3) ],
'value' => $3,
diff --git a/mount/freebsd-lib.pl b/mount/freebsd-lib.pl
index 1f98ee43d..73d0348e4 100755
--- a/mount/freebsd-lib.pl
+++ b/mount/freebsd-lib.pl
@@ -28,7 +28,7 @@ while() {
if ($p[2] eq "proc" || $p[2] eq "procfs") { $p[2] = $p[0] = "proc"; }
elsif ($p[2] eq "swap") { $p[1] = "swap"; }
elsif ($p[2] eq "smbfs") {
- # Need to get nsmb.conf options, covert share and extract user
+ # Need to get nsmb.conf options, convert share and extract user
$p[0] = lc($p[0]);
local $noptions = &read_nsmb($p[0]);
local %options;
@@ -47,7 +47,7 @@ while() {
$rv[$i]->[5] = "yes";
@o = split(/,/ , $p[3] eq "defaults" ? "" : $p[3]);
if (($j = &indexof("noauto", @o)) >= 0) {
- # filesytem is not mounted at boot
+ # filesystem is not mounted at boot
splice(@o, $j, 1);
$rv[$i]->[5] = "no";
}
@@ -182,7 +182,7 @@ while() {
if ($p[2] eq "procfs" || $p[1] eq "procfs") { $p[1] = $p[2] = "proc"; }
elsif ($p[2] eq "mfs") { $p[1] =~ s/:.*$//; }
elsif ($p[2] eq "smbfs") {
- # Need to get nsmb.conf options, covert share and extract user
+ # Need to get nsmb.conf options, convert share and extract user
$p[1] = lc($p[1]);
local $noptions = &read_nsmb($p[1]);
local %options;
diff --git a/mount/linux-lib.pl b/mount/linux-lib.pl
index 60f7c1a27..23a8ba60e 100755
--- a/mount/linux-lib.pl
+++ b/mount/linux-lib.pl
@@ -101,7 +101,7 @@ while() {
$rv[$i]->[5] = "yes";
@o = split(/,/ , $p[3] eq "defaults" ? "" : $p[3]);
if (($j = &indexof("noauto", @o)) >= 0) {
- # filesytem is not mounted at boot
+ # filesystem is not mounted at boot
splice(@o, $j, 1);
$rv[$i]->[5] = "no";
}
diff --git a/mount/netbsd-lib.pl b/mount/netbsd-lib.pl
index ba2aba1eb..7989428ff 100755
--- a/mount/netbsd-lib.pl
+++ b/mount/netbsd-lib.pl
@@ -25,7 +25,7 @@ while() {
$rv[$i]->[5] = "yes";
@o = split(/,/ , $p[3] eq "defaults" ? "" : $p[3]);
if (($j = &indexof("noauto", @o)) >= 0) {
- # filesytem is not mounted at boot
+ # filesystem is not mounted at boot
splice(@o, $j, 1);
$rv[$i]->[5] = "no";
}
diff --git a/mount/openbsd-lib.pl b/mount/openbsd-lib.pl
index a4cd806ad..df963d091 100755
--- a/mount/openbsd-lib.pl
+++ b/mount/openbsd-lib.pl
@@ -25,7 +25,7 @@ while() {
$rv[$i]->[5] = "yes";
@o = split(/,/ , $p[3] eq "defaults" ? "" : $p[3]);
if (($j = &indexof("noauto", @o)) >= 0) {
- # filesytem is not mounted at boot
+ # filesystem is not mounted at boot
splice(@o, $j, 1);
$rv[$i]->[5] = "no";
}
diff --git a/net/cygwin-lib.pl b/net/cygwin-lib.pl
index 42ccdc2e1..240c22048 100755
--- a/net/cygwin-lib.pl
+++ b/net/cygwin-lib.pl
@@ -128,7 +128,7 @@ sub apply_interface
}
# deactivate_interface(&details)
-# Deactive an interface
+# Deactivate an interface
sub deactivate_interface
{
#TODO2: determine how to deactivate an interface
diff --git a/net/debian-linux-lib.pl b/net/debian-linux-lib.pl
index 54b5d6bec..22381d129 100755
--- a/net/debian-linux-lib.pl
+++ b/net/debian-linux-lib.pl
@@ -340,7 +340,7 @@ if ($cfg->{'gateway6'}) {
push(@options6, [ "gateway", $cfg->{'gateway6'} ]);
}
-# Add, update or delete IPv6 inteface
+# Add, update or delete IPv6 interface
my $method = $cfg->{'auto6'} ? "manual" : "static";
if (!$found6 && @options6) {
# Need to add IPv6 block
diff --git a/net/freebsd-lib.pl b/net/freebsd-lib.pl
index 2f0e0263a..6ad781be7 100755
--- a/net/freebsd-lib.pl
+++ b/net/freebsd-lib.pl
@@ -119,7 +119,7 @@ if ($iface->{'virtual'} eq '') {
}
# deactivate_interface(&details)
-# Deactive an interface
+# Deactivate an interface
sub deactivate_interface
{
my ($iface) = @_;
@@ -297,7 +297,7 @@ else {
my @boot = &boot_interfaces();
my ($old) = grep { $_->{'fullname'} eq $_[0]->{'fullname'} } @boot;
if (!$old && $_[0]->{'virtual'} ne '') {
- # A new virtual interface .. pick a virtual number automaticlly
+ # A new virtual interface .. pick a virtual number automatically
my $b;
$_[0]->{'virtual'} = 0;
foreach $b (&boot_interfaces()) {
diff --git a/net/macos-lib.pl b/net/macos-lib.pl
index 0dd80cf1f..8e8404632 100755
--- a/net/macos-lib.pl
+++ b/net/macos-lib.pl
@@ -74,7 +74,7 @@ $act{$_[0]->{'fullname'}} = $_[0];
}
# deactivate_interface(&details)
-# Deactive an interface
+# Deactivate an interface
sub deactivate_interface
{
my %act;
diff --git a/net/openbsd-lib.pl b/net/openbsd-lib.pl
index 39503fd76..2dcbdde21 100755
--- a/net/openbsd-lib.pl
+++ b/net/openbsd-lib.pl
@@ -69,7 +69,7 @@ sub activate_interface
}
# deactivate_interface(&details)
-# Deactive an interface
+# Deactivate an interface
sub deactivate_interface
{
local %act;
diff --git a/net/unixware-lib.pl b/net/unixware-lib.pl
index 079b1b945..bf358d89e 100755
--- a/net/unixware-lib.pl
+++ b/net/unixware-lib.pl
@@ -64,7 +64,7 @@ if ($a->{'ether'}) {
}
# deactivate_interface(&details)
-# Deactive an interface
+# Deactivate an interface
sub deactivate_interface
{
local $cmd;
diff --git a/nis/aix-lib.pl b/nis/aix-lib.pl
index 895a27442..f2299c309 100755
--- a/nis/aix-lib.pl
+++ b/nis/aix-lib.pl
@@ -21,7 +21,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/coherent-linux-lib.pl b/nis/coherent-linux-lib.pl
index d4a9b2352..c66e8e3b3 100755
--- a/nis/coherent-linux-lib.pl
+++ b/nis/coherent-linux-lib.pl
@@ -16,7 +16,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/debian-linux-lib.pl b/nis/debian-linux-lib.pl
index 071944171..6381acf3a 100755
--- a/nis/debian-linux-lib.pl
+++ b/nis/debian-linux-lib.pl
@@ -16,7 +16,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis = { 'broadcast' => 1 };
diff --git a/nis/open-linux-lib.pl b/nis/open-linux-lib.pl
index 24e02682c..6d0bd92e2 100755
--- a/nis/open-linux-lib.pl
+++ b/nis/open-linux-lib.pl
@@ -16,7 +16,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/openmamba-linux-lib.pl b/nis/openmamba-linux-lib.pl
index fcd1076ac..f9ee15180 100755
--- a/nis/openmamba-linux-lib.pl
+++ b/nis/openmamba-linux-lib.pl
@@ -16,7 +16,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/redhat-linux-lib.pl b/nis/redhat-linux-lib.pl
index 91867d221..1f82e453f 100755
--- a/nis/redhat-linux-lib.pl
+++ b/nis/redhat-linux-lib.pl
@@ -16,7 +16,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/slackware-linux-lib.pl b/nis/slackware-linux-lib.pl
index 9efa2e413..3ace50c80 100755
--- a/nis/slackware-linux-lib.pl
+++ b/nis/slackware-linux-lib.pl
@@ -17,7 +17,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/solaris-lib.pl b/nis/solaris-lib.pl
index 15788e668..fb55bef4d 100755
--- a/nis/solaris-lib.pl
+++ b/nis/solaris-lib.pl
@@ -15,7 +15,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/suse-linux-lib.pl b/nis/suse-linux-lib.pl
index 94dbed093..ea99663c4 100755
--- a/nis/suse-linux-lib.pl
+++ b/nis/suse-linux-lib.pl
@@ -17,7 +17,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/nis/united-linux-lib.pl b/nis/united-linux-lib.pl
index d00308fdc..793796315 100755
--- a/nis/united-linux-lib.pl
+++ b/nis/united-linux-lib.pl
@@ -16,7 +16,7 @@ return $rv;
}
# get_client_config()
-# Returns a hash ref containg details of the client's NIS settings
+# Returns a hash ref containing details of the client's NIS settings
sub get_client_config
{
local $nis;
diff --git a/old-blue-theme/left.cgi b/old-blue-theme/left.cgi
index 65114d721..283f6357a 100755
--- a/old-blue-theme/left.cgi
+++ b/old-blue-theme/left.cgi
@@ -102,7 +102,7 @@ if (&get_product_name() eq 'webmin' && # For Webmin
'icon' => '/images/mail-small.gif' });
}
-# Show refesh modules link, for master admin
+# Show refresh modules link, for master admin
if (&foreign_available("webmin")) {
push(@leftmenu, { 'type' => 'item',
'desc' => $text{'main_refreshmods'},
diff --git a/package-updates/package-updates-lib.pl b/package-updates/package-updates-lib.pl
index ccccd048f..2c06c0f17 100644
--- a/package-updates/package-updates-lib.pl
+++ b/package-updates/package-updates-lib.pl
@@ -666,7 +666,7 @@ unlink($available_cache_file.'1');
}
# list_for_mode(mode, nocache)
-# If not is 'updates' or 'security', return just updates. Othewise, return
+# If not is 'updates' or 'security', return just updates. Otherwise, return
# all available packages.
sub list_for_mode
{
diff --git a/postfix/help/body.html b/postfix/help/body.html
index 44b86d5db..e0ac62a2c 100644
--- a/postfix/help/body.html
+++ b/postfix/help/body.html
@@ -1,6 +1,6 @@
-The optional header checks table allows email to be redirected based on the contents of the mesage body. Each entry in the table has a POSIX regular expression on the left-hand side, and an action on the right.
+The optional header checks table allows email to be redirected based on the contents of the message body. Each entry in the table has a POSIX regular expression on the left-hand side, and an action on the right.
The regular expression can be something like :
/make.money.fast/
diff --git a/qmailadmin/delete_queues.cgi b/qmailadmin/delete_queues.cgi
index 884e9c9b2..f9a0e406b 100755
--- a/qmailadmin/delete_queues.cgi
+++ b/qmailadmin/delete_queues.cgi
@@ -1,6 +1,6 @@
#!/usr/local/bin/perl
# delete_queue.cgi
-# Delete multiple mail messsages from the queue
+# Delete multiple mail messages from the queue
require './qmail-lib.pl';
&ReadParse();
diff --git a/quota/linux-lib.pl b/quota/linux-lib.pl
index 21e6783d7..d71eac16a 100755
--- a/quota/linux-lib.pl
+++ b/quota/linux-lib.pl
@@ -357,7 +357,7 @@ return undef;
=head2 run_quotacheck(filesys, args)
-Runs the quotacheck command on some filesytem, and returns 1 on success or
+Runs the quotacheck command on some filesystem, and returns 1 on success or
0 on failure. Mainly for internal use when enabling quotas.
=cut
diff --git a/quota/quota-lib.pl b/quota/quota-lib.pl
index 093854282..8121098c1 100755
--- a/quota/quota-lib.pl
+++ b/quota/quota-lib.pl
@@ -405,7 +405,7 @@ if ($in{$_[0]."_def"} && !$_[2]) {
return 0;
}
elsif ($_[1]) {
- # Include units, and covert to blocks
+ # Include units, and convert to blocks
return int($in{$_[0]}*$in{$_[0]."_units"}/$_[1]);
}
else {
diff --git a/raid/raid-lib.pl b/raid/raid-lib.pl
index 230eb76c8..fef7b71c1 100755
--- a/raid/raid-lib.pl
+++ b/raid/raid-lib.pl
@@ -489,7 +489,7 @@ if ($raid_mode eq "mdadm") {
}
# convert_raid(&raid, oldcount, newcount, level)
-# Converts a RAID set to a defferent level RAID set
+# Converts a RAID set to a different level RAID set
sub convert_raid
{
if ($raid_mode eq "mdadm") {
@@ -781,7 +781,7 @@ return 0;
}
# save_mdadm_monitoring(enabled)
-# Tries to enable or disable mdadm monitoring. Returns an error mesage
+# Tries to enable or disable mdadm monitoring. Returns an error message
# if something goes wrong, undef on success
sub save_mdadm_monitoring
{
diff --git a/sendmail/lang/en b/sendmail/lang/en
index 66bfff9b6..9ece338c8 100644
--- a/sendmail/lang/en
+++ b/sendmail/lang/en
@@ -171,7 +171,7 @@ masq_ecannot=You are not allowed to configure masquerading
masq_domain=Masquerade as domain
masq_domains=Domains to be masqueraded
masq_ndomains=Domains not to masquerade
-masq_desc1=If a domain is given below, sendmail will alter the From address of all outgoing messages to appear to come from that domain. In addition, any email messages passing through your system from one of the hosts or domains listed below will also have their From addresses modified in the same way. Note that any domain masquerading defined here can be overriden for specific users using the Outgoing Addresses page.
+masq_desc1=If a domain is given below, sendmail will alter the From address of all outgoing messages to appear to come from that domain. In addition, any email messages passing through your system from one of the hosts or domains listed below will also have their From addresses modified in the same way. Note that any domain masquerading defined here can be overridden for specific users using the Outgoing Addresses page.
masq_desc2=This feature can be useful if you want email from your system to appear to come from your domain name rather than your hostname, or if your system is the mail hub for number of other hosts running their own mailservers.
masq_err=Failed to save domain masquerading
masq_edomain='$1' is not a valid domain to masquerade as
diff --git a/sentry/help/hostsentry.html b/sentry/help/hostsentry.html
index 8fb358d92..5740e5898 100644
--- a/sentry/help/hostsentry.html
+++ b/sentry/help/hostsentry.html
@@ -27,7 +27,7 @@ The available options are :
to reporting.
- Hosts to trust multiple logins from
- If the 'Detect multiple similtaneous logins' module is enabled, two or
+ If the 'Detect multiple simultaneous logins' module is enabled, two or
more logins by the same user at the same time from a host not in this
list will be reported.
diff --git a/servers/delete_servs.cgi b/servers/delete_servs.cgi
index d470dcbf9..d9d4e4efb 100755
--- a/servers/delete_servs.cgi
+++ b/servers/delete_servs.cgi
@@ -1,5 +1,5 @@
#!/usr/local/bin/perl
-# Delete serveral servers at once
+# Delete several servers at once
use strict;
use warnings;
diff --git a/setup.bat b/setup.bat
index f8f2d2e1e..b9cb4f296 100644
--- a/setup.bat
+++ b/setup.bat
@@ -4,7 +4,7 @@ ECHO UNOFFICIAL helper script to guide less experienced users on Windows
ECHO for information on installing webmin on Windows manually see:
ECHO http://www.webmin.com/windows.html
ECHO .
-ECHO NOTE: Webmin on Windows is community provided and not suppored officially!
+ECHO NOTE: Webmin on Windows is community provided and not supported officially!
ECHO last reported working insallations was on Windows 8.1
ECHO .
@@ -69,7 +69,7 @@ IF %ERRORLEVEL% NEQ 0 (
SET INSTALL=false
)
-:: check if rescource kit is installed
+:: check if resource kit is installed
WHERE sc >nul 2>&1
IF %ERRORLEVEL% NEQ 0 (
ECHO Windows Resource Toolkit is not installed you may not able to run Webmin as a Service!
@@ -91,7 +91,7 @@ IF NOT EXIST %inst_dir% (
IF EXIST %INSTALL% (
- :: install perl module win::deamon if not installed
+ :: install perl module win::daemon if not installed
IF NOT EXIST %perl_path%\site\lib\Win32\Daemon.pm (
ppm install Win32-Daemon
)
@@ -101,7 +101,7 @@ IF EXIST %INSTALL% (
ECHO Webmin can not installed because of missing prerequisites!
ECHO see http://www.webmin.com/windows.html for manual installation instructions
ECHO .
- ECHO If you are able to improve/fix installtion on newer Windows Versions report them pls
+ ECHO If you are able to improve/fix installation on newer Windows Versions report them pls
)
ECHO .
PAUSE
diff --git a/setup.pl b/setup.pl
index 44854ae05..6c1589d14 100755
--- a/setup.pl
+++ b/setup.pl
@@ -423,7 +423,7 @@ else {
}
&put_miniserv_config(\%miniserv);
- # Test availble hashing formats
+ # Test available hashing formats
if (&unix_crypt('test', '$y$j9T$waHytoaqP/CEnKFroGn0S/$fxd5mVc2mBPUc3vv.cpqDckpwrWTyIm2iD4JfnVBi26') eq '$y$j9T$waHytoaqP/CEnKFroGn0S/$fxd5mVc2mBPUc3vv.cpqDckpwrWTyIm2iD4JfnVBi26') {
$yescryptpass = 1;
}
diff --git a/setup.sh b/setup.sh
index 33cd7a35d..30e4efb91 100755
--- a/setup.sh
+++ b/setup.sh
@@ -535,7 +535,7 @@ else
cat "$wadir/miniserv-conf" >>$cfile
fi
- # Test availble hashing formats
+ # Test available hashing formats
yescryptpass=`$perl -e 'print crypt("test", "\\$y\\$j9T\\$waHytoaqP/CEnKFroGn0S/\\$fxd5mVc2mBPUc3vv.cpqDckpwrWTyIm2iD4JfnVBi26") eq "\\$y\\$j9T\\$waHytoaqP/CEnKFroGn0S/\\$fxd5mVc2mBPUc3vv.cpqDckpwrWTyIm2iD4JfnVBi26" ? "1\n" : "0\n"'`
sha512pass=`$perl -e 'print crypt("test", "\\$6\\$Tk5o/GEE\\$zjvXhYf/dr5M7/jan3pgunkNrAsKmQO9r5O8sr/Cr1hFOLkWmsH4iE9hhqdmHwXd5Pzm4ubBWTEjtMeC.h5qv1") eq "\\$6\\$Tk5o/GEE\\$zjvXhYf/dr5M7/jan3pgunkNrAsKmQO9r5O8sr/Cr1hFOLkWmsH4iE9hhqdmHwXd5Pzm4ubBWTEjtMeC.h5qv1" ? "1\n" : "0\n"'`
md5pass=`$perl -e 'print crypt("test", "\\$1\\$A9wB3O18\\$zaZgqrEmb9VNltWTL454R/") eq "\\$1\\$A9wB3O18\\$zaZgqrEmb9VNltWTL454R/" ? "1\n" : "0\n"'`
diff --git a/shorewall/shorewall-lib.pl b/shorewall/shorewall-lib.pl
index 20d49df92..79b37bf72 100755
--- a/shorewall/shorewall-lib.pl
+++ b/shorewall/shorewall-lib.pl
@@ -1881,7 +1881,7 @@ else {
}
# run_before_apply_command()
-# Runs the before-applying command, if any. If it failes, returns the error
+# Runs the before-applying command, if any. If it fails, returns the error
# message output
sub run_before_apply_command
{
diff --git a/shorewall6/shorewall6-lib.pl b/shorewall6/shorewall6-lib.pl
index 7ee11fa49..3965ff7f9 100755
--- a/shorewall6/shorewall6-lib.pl
+++ b/shorewall6/shorewall6-lib.pl
@@ -1531,7 +1531,7 @@ else {
}
# run_before_apply_command()
-# Runs the before-applying command, if any. If it failes, returns the error
+# Runs the before-applying command, if any. If it fails, returns the error
# message output
sub run_before_apply_command
{
diff --git a/smf/help/help.html b/smf/help/help.html
index fa721ea5f..2e16c1906 100644
--- a/smf/help/help.html
+++ b/smf/help/help.html
@@ -4,7 +4,7 @@
Introduction
This module allows you to view/modify/update/add SMF services in Solaris
10. The main page consists of a listing of services, and you can select a
-specific category, view disabled serivces, sort entries etc. From here you
+specific category, view disabled services, sort entries etc. From here you
can also launch a wizard-type utility that manages service creation, view
the service state, dependencies/dependent, and view property groups/properties
for each service.
@@ -13,7 +13,7 @@ for each service.
By default, main SMF module window lists the enabled services on the system,
showing their states, the FMRI that identifies the service, and the description
that is supplied with the service. You can apply state changes to multiple
-services by checking the desired serivces, and clicking enable/disable etc.
+services by checking the desired services, and clicking enable/disable etc.
You can also delete the service instances specified, but obviously avoid doing
this for important services.
@@ -45,7 +45,7 @@ you want to change. Clicking on an instance FMRI brings up the dependency/
dependent trees for that instance.
Service Creation Wizard
-Clicking the "Create New Serivce" button brings up the SMF service creation
+Clicking the "Create New Service" button brings up the SMF service creation
wizard, which collects the required information to create a new SMF service,
formats it into a manifest and imports it into the SMF repository. Successful
import will result in the service appearing in the main services listing.
diff --git a/smf/help/property_group_editor_detail.html b/smf/help/property_group_editor_detail.html
index f18bcd70f..800cb1737 100644
--- a/smf/help/property_group_editor_detail.html
+++ b/smf/help/property_group_editor_detail.html
@@ -5,7 +5,7 @@
The information displayed on this page corresponds to the list of
service property groups for both the service and selected instance.
Service-level property groups are displayed since their associated
-properties are inherited by the instance unless they are overriden.
+properties are inherited by the instance unless they are overridden.
Clicking the property group name allows viewing/editing of individual
properties within the selected property group. Property groups can
also be added/deleted here.
diff --git a/smf/smf-lib.pl b/smf/smf-lib.pl
index 20486d720..93e876d99 100755
--- a/smf/smf-lib.pl
+++ b/smf/smf-lib.pl
@@ -553,7 +553,7 @@ if (($service_info{'template_common_name'} =~ /.+/) &&
\@find_replace_array);
}
-# subfunction to add dependecy/dependent/exec method/propgroup/prop
+# subfunction to add dependency/dependent/exec method/propgroup/prop
# information to manifest. if at service level, we look for sinst=service,
# otherwise, look for matches to instance name
#
diff --git a/software/csw-lib.pl b/software/csw-lib.pl
index 9af9c18e9..456d5b0cd 100755
--- a/software/csw-lib.pl
+++ b/software/csw-lib.pl
@@ -50,7 +50,7 @@ do {
$failed = 1;
}
elsif (/dependency\s+(\S+)\s+.*not up to date/i) {
- # Needs a dependecy .. so we will need to re-run!
+ # Needs a dependency .. so we will need to re-run!
local $dep = $1;
$update = join(" ", &unique(
$dep, split(/\s+/, $update)));
diff --git a/software/hpux-lib.pl b/software/hpux-lib.pl
index 646505474..d614628f4 100755
--- a/software/hpux-lib.pl
+++ b/software/hpux-lib.pl
@@ -35,7 +35,7 @@ while() {
}
$title_flag = "";
}
-# bundeled products
+# bundled products
if (/^contents\s+(.*)/) {
@contents = split(/\./, $1);
$packages{$i,'name'} = "$name.$contents[0]";
diff --git a/software/ipkg-edit_pack.cgi b/software/ipkg-edit_pack.cgi
index e73a8c484..2a192d611 100755
--- a/software/ipkg-edit_pack.cgi
+++ b/software/ipkg-edit_pack.cgi
@@ -31,7 +31,7 @@ if (!$pinfo[7]) {
&ui_hidden("version", $pinfo[4]).
&ui_hidden("search", $in{'search'}));
} else {
-# Show botton to install
+# Show button to install
print &ui_buttons_row("install_pack.cgi",
$text{'IPKG_install_package'},
$text{'IPKG_install_packagedesc'},
diff --git a/software/ipkg-tree.cgi b/software/ipkg-tree.cgi
index 08c776e5f..dc6f8eab6 100755
--- a/software/ipkg-tree.cgi
+++ b/software/ipkg-tree.cgi
@@ -22,7 +22,7 @@ if ($in{'filter'}) {
}
}
-# prcoess openall / closeall actions
+# process openall / closeall actions
if ( $in{'mode'} eq "closeall" ) {
&save_heiropen([ ]);
}
diff --git a/software/ports-lib.pl b/software/ports-lib.pl
index 385f368cd..4cd4bc5de 100644
--- a/software/ports-lib.pl
+++ b/software/ports-lib.pl
@@ -1,7 +1,7 @@
# Functions for FreeBSD ports / package management
# update_system_install([package], [&in])
-# Install a named package, by buiding the port
+# Install a named package, by building the port
sub update_system_install
{
my ($update, $in) = @_;
diff --git a/software/tree.cgi b/software/tree.cgi
index 30686915e..2eb71d549 100755
--- a/software/tree.cgi
+++ b/software/tree.cgi
@@ -20,7 +20,7 @@ if ($in{'filter'}) {
}
}
-# prcoess openall / closeall actions
+# process openall / closeall actions
if ( $in{'mode'} eq "closeall" ) {
&save_heiropen([ ]);
}
diff --git a/squid/help/edit_acl.html b/squid/help/edit_acl.html
index f81588d70..76eb9e560 100644
--- a/squid/help/edit_acl.html
+++ b/squid/help/edit_acl.html
@@ -10,7 +10,7 @@ The fields present are:
Matching.. is the address, port, URL, user, etc. that the ACL will be matching to.
-Proxy restrictions: Proxy restrictions are rules that either allow or deny a given request based on whether its ACL matches the specifics of the reuqest. There are three fields in this box.
+Proxy restrictions: Proxy restrictions are rules that either allow or deny a given request based on whether its ACL matches the specifics of the request. There are three fields in this box.
Action is either allow or deny.
diff --git a/squid/help/edit_pool.html b/squid/help/edit_pool.html
index 7d9a74b63..fcfc3bb59 100644
--- a/squid/help/edit_pool.html
+++ b/squid/help/edit_pool.html
@@ -7,7 +7,7 @@
Pool class
-This defines the class type of the pool. Each delay pool can have a class selected from classes 1, 2 or 3. The classes have the following meanings: "1-Aggregate", "2-Aggregate and Individual", "3-Aggregate, Individual, and Network". The simplest, class 1, specifies a bandwidth that all clients to which this pool belongs cannot surpass. Class 2 specifies both an aggregate bandwidth and a bandwidth that each individual can use, creating a heirarchy of limits where all individuals combined must fit into the aggregate while each individual is limited by the individual limit. Finally, Class 3 specifies an aggregate and individual bandwith in addition to a network bandwidth which applies to an entire subnet. Class 3 is usually only useful on very large networks that have more than one network subnet.
+This defines the class type of the pool. Each delay pool can have a class selected from classes 1, 2 or 3. The classes have the following meanings: "1-Aggregate", "2-Aggregate and Individual", "3-Aggregate, Individual, and Network". The simplest, class 1, specifies a bandwidth that all clients to which this pool belongs cannot surpass. Class 2 specifies both an aggregate bandwidth and a bandwidth that each individual can use, creating a hierarchy of limits where all individuals combined must fit into the aggregate while each individual is limited by the individual limit. Finally, Class 3 specifies an aggregate and individual bandwidth in addition to a network bandwidth which applies to an entire subnet. Class 3 is usually only useful on very large networks that have more than one network subnet.
Limits can be specified in any unit preferred, though it will be saved to the Squid configuration file in bytes. The first field is the average throughput that will be allotted to the pool, while the second is the size of the bucket used, which roughly corresponds to a burstable bandwidth maximum.
diff --git a/system-status/system_info.pl b/system-status/system_info.pl
index 5f4dec685..62f20d5f5 100644
--- a/system-status/system_info.pl
+++ b/system-status/system_info.pl
@@ -232,7 +232,7 @@ if ($info->{'disk_total'} && &show_section('disk')) {
'chart' => [ $total, $total-$free ] });
}
-# Warnings about filesytems running now on space
+# Warnings about filesystems running low on space
if ($info->{'disk_fs'} && &show_section('disk')) {
foreach my $fs (@{$info->{'disk_fs'}}) {
next if (!$fs->{'total'});
diff --git a/update-from-repo.sh b/update-from-repo.sh
index 63a04bbd5..7d1b255d2 100755
--- a/update-from-repo.sh
+++ b/update-from-repo.sh
@@ -102,7 +102,7 @@ Parameters:
pull a released version, default: -release:latest
-file
pull only the given file(s) or dir(s)/ from repo
- dir has to be specified with trailling '/'
+ dir has to be specified with trailing '/'
file or dir/ must not start with a slash and
must not contain '../'
-h
@@ -384,7 +384,7 @@ fi
fi
else
##################
- # pull specifed files only
+ # pull specified files only
shift
FILES="$*"
for file in ${FILES}
diff --git a/uptracker.cgi b/uptracker.cgi
index 1af99a7ec..588160ed7 100755
--- a/uptracker.cgi
+++ b/uptracker.cgi
@@ -27,7 +27,7 @@ print "
",&ui_textbox("pc", undef, 50, 1, undef, $ff)," | \n";
print "\n";
print "\n";
-# Find the location of the user's upload progess file
+# Find the location of the user's upload progress file
if ($in{'uid'}) {
@uinfo = getpwuid($in{'uid'});
$upfile = "$uinfo[7]/.tmp/upload.$id";
diff --git a/useradmin/help/max.html b/useradmin/help/max.html
index 7b4c1b87c..f4c53e843 100644
--- a/useradmin/help/max.html
+++ b/useradmin/help/max.html
@@ -1,5 +1,5 @@
-
-This is the maxmimum number of days allowed between password changes.
+
+This is the maximum number of days allowed between password changes.
After this time has elapsed, the user will be propted to enter a new
password at login.
diff --git a/useradmin/help/max_weeks.html b/useradmin/help/max_weeks.html
index a229dbe4e..5c2c3f7fc 100644
--- a/useradmin/help/max_weeks.html
+++ b/useradmin/help/max_weeks.html
@@ -1,5 +1,5 @@
-
-This is the maxmimum number of weeks allowed between password changes.
+
+This is the maximum number of weeks allowed between password changes.
After this time has elapsed, the user will be prompted to enter a new
password at login.
diff --git a/useradmin/lang/en b/useradmin/lang/en
index 2f026ab9e..020f9a05f 100644
--- a/useradmin/lang/en
+++ b/useradmin/lang/en
@@ -319,9 +319,9 @@ acl_ucreate=Can create new users?
acl_uid=UIDs for new or modified users
acl_umultiple=More than one user can have the same UID
acl_uuid=UIDs of existing users can be changed
-acl_ugroups=Allowed groups for new or modifed users
+acl_ugroups=Allowed groups for new or modified users
acl_all=All
-acl_shells=Allowed shells for new or modifed users
+acl_shells=Allowed shells for new or modified users
acl_any=Any
acl_listed=Listed..
acl_home=Home directories must be under
diff --git a/useradmin/user-lib.pl b/useradmin/user-lib.pl
index 22127141b..a3d52b5c9 100755
--- a/useradmin/user-lib.pl
+++ b/useradmin/user-lib.pl
@@ -2453,7 +2453,7 @@ foreach $g (@$groups) {
local $members = join(" ", split(/,/, $g->{'members'}));
local @cols;
if ($anyedit && ($g->{'noedit'} || !$access{'gdelete'})) {
- # Need an explicity blank first column
+ # Need an explicitly blank first column
push(@cols, "");
}
push(@cols, &group_link($g));
diff --git a/web-lib-funcs.pl b/web-lib-funcs.pl
index 25a3455db..e68ac95c6 100755
--- a/web-lib-funcs.pl
+++ b/web-lib-funcs.pl
@@ -275,7 +275,7 @@ return $str;
=head2 quote_escape(string, [only-quote])
Converts ' and " characters in a string into HTML entities, and returns it.
-Useful for outputing HTML tag values.
+Useful for outputting HTML tag values.
=cut
sub quote_escape
@@ -425,7 +425,7 @@ return $rv;
Behaves exactly like transname, but returns a filename with current timestamp
-=item filename - Optional filename prefix to preppend
+=item filename - Optional filename prefix to prepend
=item extension - Optional extension for a filename to append
@@ -3794,7 +3794,7 @@ return 0;
=head2 foreign_available(module)
-Returns 1 if some module is installed, and acessible to the current user. The
+Returns 1 if some module is installed, and accessible to the current user. The
module parameter is the module directory name.
=cut
@@ -5614,7 +5614,7 @@ return $_;
=head2 get_module_info(module, [noclone], [forcache])
-Returns a hash containg details of the given module. Some useful keys are :
+Returns a hash containing details of the given module. Some useful keys are :
=item dir - The module directory, like sendmail.
@@ -11366,7 +11366,7 @@ if ($force ||
!$main::connect_userdb_cache{$str} ||
time() - $main::connect_userdb_cache_time{$str} > $timeout) {
if ($str =~ /^(mysql|postgresql):/) {
- # DBI disconnnect
+ # DBI disconnect
if (!$h->{'AutoCommit'}) {
$h->commit();
}
@@ -12124,7 +12124,7 @@ sub webmin_user_can_rpc
{
my $u = $base_remote_user;
my %access = &get_module_acl($u, "");
-return 1 if ($access{'rpc'} == 1); # Can make arbitary RPC calls
+return 1 if ($access{'rpc'} == 1); # Can make arbitrary RPC calls
return 0 if ($access{'rpc'} == 0); # Cannot make RPCs
# Assume that standard admin usernames
diff --git a/wuftpd/lang/en b/wuftpd/lang/en
index dfa511e8c..0b9249fbb 100644
--- a/wuftpd/lang/en
+++ b/wuftpd/lang/en
@@ -43,7 +43,7 @@ message_dir=Entering dir
message_alldir=Entering any dir
message_classes=Classes to display for
message_readme=README files
-message_update=When to display last modifed date
+message_update=When to display last modified date
message_greeting=Greeting level
message_full=Hostname and version
message_brief=Hostname
diff --git a/net/solaris-lib.pl b/net/solaris-lib.pl
index de3ba5229..02264c302 100755
--- a/net/solaris-lib.pl
+++ b/net/solaris-lib.pl
@@ -131,7 +131,7 @@ if ($a->{'ether'}) {
}
# deactivate_interface(&details)
# Deactive an interface
sub deactivate_interface
{
local $a = $_[0];
@@ -764,7 +764,7 @@ foreach $b (&boot_interfaces()) {
foreach $a (&active_interfaces()) {
next if ($a->{'name'} eq 'lo0');
if (!$done{$a->{'fullname'}} && !$a->{'zone'}) {
- &deactive_interface($a);
+ &deactivate_interface($a);
}
}
@@ -131,7 +131,7 @@ if ($a->{'ether'}) {
}
# deactivate_interface(&details)
-# Deactive an interface
+# Deactivate an interface
sub deactivate_interface
{